@@ -288,6 +288,11 @@ hildon_file_system_root_get_folder (HildonFileSystemSpecialLocation *location,
   root_folder->root = HILDON_FILE_SYSTEM_ROOT (location);
   g_object_ref (location);
 
+  /* This tells the HildonFileSystemModel never to call
+     gtk_file_system_cancel_operation on this handle.
+  */
+  handle->file_system = NULL;
+
   clos->handle = handle;
   clos->root_folder = root_folder;
   clos->callback = callback;
